@@ -64,7 +64,7 @@ Astro::Coord::ECI::Meta - Information needed to build Astro::Coord::ECI
  use lib qw{ inc };
  use Astro::Coord::ECI::Meta;
  my $meta = Astro::Coord::ECI::Meta->new();
- use YAML;
+ use YAML::Any;
  print "Required modules:\n", Dump(
      $meta->requires() );
 
@@ -86,7 +86,7 @@ This method instantiates the class.
 
 =head2 build_requires
 
- use YAML;
+ use YAML::Any;
  print Dump( $meta->build_requires() );
 
 This method computes and returns a reference to a hash describing the
@@ -107,7 +107,7 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 =head2 requires
 
- use YAML;
+ use YAML::Any;
  print Dump( $meta->requires() );
 
 This method computes and returns a reference to a hash describing
@@ -149,7 +149,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2011 by Thomas R. Wyant, III
+Copyright (C) 2010-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
